From b513b776a871452889f3307ea6887a95f3750be1 Mon Sep 17 00:00:00 2001
From: Rex Zhu <Rex.Zhu@amd.com>
Date: Thu, 13 Oct 2016 15:17:22 +0800
Subject: [PATCH 1/3] drm/amdgpu: need to disable dpm first when rmmod amdgpu.

otherwise, the dpm can't be disabled

Change-Id: Ia318f7bbcda1f0b1841c0198fd0fdbc93afc0adf
Signed-off-by: Rex Zhu <Rex.Zhu@amd.com>
---
 drivers/gpu/drm/amd/amdgpu/amdgpu_device.c | 9 +++++++++
 1 file changed, 9 insertions(+)

diff --git a/drivers/gpu/drm/amd/amdgpu/amdgpu_device.c b/drivers/gpu/drm/amd/amdgpu/amdgpu_device.c
index 60d63bf..bfd830a 100644
--- a/drivers/gpu/drm/amd/amdgpu/amdgpu_device.c
+++ b/drivers/gpu/drm/amd/amdgpu/amdgpu_device.c
@@ -1444,6 +1444,13 @@ static int amdgpu_fini(struct amdgpu_device *adev)
 {
 	int i, r;
 
+	r = adev->ip_blocks[AMD_IP_BLOCK_TYPE_SMC].funcs->hw_fini((void *)adev);
+	if (r)
+		DRM_DEBUG("hw_fini of IP block <%s> failed %d\n",
+			adev->ip_blocks[AMD_IP_BLOCK_TYPE_SMC].funcs->name, r);
+
+	adev->ip_block_status[AMD_IP_BLOCK_TYPE_SMC].hw = false;
+
 	for (i = adev->num_ip_blocks - 1; i >= 0; i--) {
 		if (!adev->ip_block_status[i].hw)
 			continue;
@@ -1451,6 +1458,8 @@ static int amdgpu_fini(struct amdgpu_device *adev)
 			amdgpu_wb_fini(adev);
 			amdgpu_vram_scratch_fini(adev);
 		}
+
+
 		/* ungate blocks before hw fini so that we can shutdown the blocks safely */
 		r = adev->ip_blocks[i].funcs->set_clockgating_state((void *)adev,
 								    AMD_CG_STATE_UNGATE);
-- 
1.9.1

